@@ -31,7 +31,7 @@ from pyspark.sql.functions import expr as spark_expr
 from pyspark.sql.functions import lit as spark_lit
 from pyspark.sql.types import StructField, StringType, BooleanType
 
-from dora_lakehouse import logger
+from dora_lakehouse.utils import logger, walk
 from dora_lakehouse.catalog import Table
 from dora_lakehouse.datatable import DataTable, HASH_COL, IDX_COL, NAME_SIZE, DEL_COL
 
@@ -74,7 +74,7 @@ def _move_(path_from:str, path_to:str, file_type:str):
     # For each key, move and rename files
     for hash_key in clean_file_system(path_from, temporary=True):
         dir_to_search=Path(f"{path_from}/{HASH_COL}={hash_key}")
-        for _file in _walk_(dir_to_search, file_type):
+        for _file in walk(dir_to_search, file_type):
             dest_dir = '/'.join(str(_file).replace(str(dir_to_search),str(path_to)).split('/')[:-1])
             destiny = Path(f"{dest_dir}/{hash_key}.{file_type}")
             logger.debug("MOVE:%s:TO:%s", _file, destiny)
@@ -85,16 +85,6 @@ def _move_(path_from:str, path_to:str, file_type:str):
     logger.debug("REMOVING:%s", path_from)
     shutil.rmtree(Path(path_from), ignore_errors=True)
 
-
-def _walk_(path:Path, file_type:str):
-    """Walk into directory and recovery the file names"""
-    for dirpath, dirnames, filenames in os.walk(path):
-        for dirname in dirnames:
-            filenames.append(_walk_(os.path.join(dirpath, dirname),file_type))
-        for filename in filenames:
-            if str(filename).endswith(file_type): # If are an valid file
-                yield os.path.join(dirpath, filename)
-
 def _exists_(path:Path, key:str):
     """Discover if there are some key in use"""
     for dirpath, dirnames, filenames in os.walk(path):
@@ -344,7 +334,7 @@ class Context(SQLContext, ABC):
             self.write_master(data_table)
         path = self._rfn_path_(data_table.table, ".rfn")
         logger.debug("REFINED:STAGE:%s", path)
-        data_table.filter(f"{DEL_COL} is false")\
+        data_table.filter(f"{DEL_COL} = false")\
             .orderBy(data_table.keys)\
             .repartition(1, HASH_COL)\
             .write.partitionBy([HASH_COL]+[_par.name for _par in data_table.table.partitions])\
